<?php
/**
 * Admin: File Scanner
 *
 * @package Look-See Security Scanner
 * @author  Blobfolio, LLC <hello@blobfolio.com>
 */

/**
 * Do not execute this file directly.
 */
if (!defined('ABSPATH')) {
	exit;
}

use \blobfolio\wp\looksee\admin;
use \blobfolio\wp\looksee\ajax;
use \blobfolio\wp\looksee\files;
use \blobfolio\wp\looksee\options;
use \blobfolio\wp\looksee\scan;
use \blobfolio\wp\looksee\vendor\common;

$data = array(
	'forms'=>array(
		'scan'=>array(
			'action'=>'looksee_ajax_scan',
			'n'=>ajax::get_nonce(),
			'scan_id'=>0,
			'tries'=>0,
			'progress'=>0.0,
			'status'=>'',
			'statusText'=>'',
			'errors'=>array(),
			'loading'=>false,
		),
		'file'=>array(
			'action'=>'looksee_ajax_file_',
			'n'=>ajax::get_nonce(),
			'scan_id'=>0,
			'file_path'=>'',
			'file_hash'=>'',
			'errors'=>array(),
			'confirming'=>false,
			'loading'=>false,
		),
		'history'=>array(
			'action'=>'looksee_ajax_scan_history',
			'n'=>ajax::get_nonce(),
			'errors'=>array(),
			'loading'=>false,
		),
		'abort'=>array(
			'action'=>'looksee_ajax_scan_abort',
			'n'=>ajax::get_nonce(),
			'errors'=>array(),
			'loading'=>false,
			'saved'=>false,
		),
		'settings'=>array(
			'action'=>'looksee_ajax_settings',
			'n'=>ajax::get_nonce(),
			'errors'=>array(),
			'saved'=>false,
			'loading'=>false,
		),
	),
	'modal'=>false,
	'modals'=>array(
		// @codingStandardsIgnoreStart
		'checksums'=>array(
			__('Yay! This particular package had clean, authoritative source files available for use during this scan. No matter what state your server was in, file irregularities were easy to detect.', LOOKSEE_L10N),
			__('Note: WordPress does not maintain a proper release history for the themes and plugins it hosts, so this critical security feature will only work if your themes and plugins are up-to-date.', LOOKSEE_L10N),
		),
		'scan-blacklist'=>array(
			sprintf(
				__("You can skip any arbitrary file or directory. Paths should be relative to your site's base directory, so for example, to skip the file %s, enter %s. To skip the contents of a directory, use a wildcard character, like %s.", LOOKSEE_L10N),
				'<code style="word-wrap: break-word;">' . files::get_base_dir() . 'index.php</code>',
				'<code>index.php</code>',
				'<code>foobar/*</code>'
			),
			sprintf(
				__('You can also use wildcards to skip certain types of files. For example, you could use %s to avoid scanning any JPEG files in the uploads directory, or just %s to skip any JPEG files anywhere.', LOOKSEE_L10N),
				'<code>' . files::get_uploads_dir() . '*.jpg</code>',
				'<code>*.jpg</code>'
			),
		),
		'scan-skip_cache'=>array(
			sprintf(
				__('Static cache files generated by plugins like %s and %s are probably not very useful to include in a scan. By their nature, they are short-lived, and will likely show up as "modified" every time a scan is performed. And because they are generated from dynamic theme and plugin content – which is also scanned – their inclusion is a bit redundant.', LOOKSEE_L10N),
				'<a href="https://wordpress.org/plugins/w3-total-cache/" target="_blank" rel="noopener">W3TC</a>',
				'<a href="https://wordpress.org/plugins/wp-super-cache/" target="_blank" rel="noopener">WP Super Cache</a>'
			),
			sprintf(
				__('When this option is enabled, files found in %s will be skipped.', LOOKSEE_L10N),
				'<code>' . files::get_content_dir() . 'cache/</code>'
			),
		),
		'scan-skip_images'=>array(
			__('This quick filter will auto-skip (most) images in your uploads directory. Images can be malicious, so in general you should include them in your scans.', LOOKSEE_L10N
				),
			__('But images can also be *big* and might pose problems for underpowered servers. Even on a strong server, an old site with a lot of content might end up taking unacceptably long to scan.', LOOKSEE_L10N),
			__('TL;DR if the scans are timing out or taking too long to complete, maybe try this option.', LOOKSEE_L10N)
		),
		'scan-skip_media'=>array(
			__('This quick filter will auto-skip (most) audio/video files in your uploads directory. Due to their large size, these files are not yet very common transmission vectors of malicious code — excepting pornography — and so are probably fairly safe to skip.', LOOKSEE_L10N
				),
			__("If your server is adequately powered and/or you don't have much in the way of audio/video content, leave this disabled. Otherwise if your server is having trouble completing scans, turn this on.", LOOKSEE_L10N),
		),
		'scan-skip_size'=>array(
			__('Malicious content is almost always going to be embedded in executable files like PHP scripts, which are relatively small.', LOOKSEE_L10N),
			__('Larger files, like images and video, are not likely targets and require more time and processing power to scan. On many low-end hosting environments, this can lead to timeout errors and other problems.', LOOKSEE_L10N),
			__('It is recommended everyone set a sane limit on the maximum file size that should be scanned. For VPS hosting, a value of 5MB or 10MB should be plenty. Shared hosting might need a lower limit, like 1MB or 2MB.', LOOKSEE_L10N),
			__('To disable the cap and scan everything, set the value to 0MB.', LOOKSEE_L10N),
		),
		'scan-batch_size'=>array(
			__('In-depth file scanning is a resource-intensive task and so is executed in workable chunks. This option specifies the number of files to attempt to scan in a single pass.', LOOKSEE_L10N),
			__('If you are frequently receiving timeout errors when running scans, try decreasing this number.', LOOKSEE_L10N),
		),
		'prune-active'=>array(
			__('Thousands of records might be added to the database each time a file scan is performed. While Look-See has taken care to store this data efficiently, it can still add up over time.', LOOKSEE_L10N),
			__('Enable this option to have old records for completed scans automatically removed.', LOOKSEE_L10N),
		),
		'prune-limit'=>array(
			__('This option specifies the maximum number of completed scans to store in the database.', LOOKSEE_L10N),
			__('Certain scan operations rely on there being a decent history, so try to avoid setting this too low. For most sites, a value of 10 is probably fine.', LOOKSEE_L10N),
			__('Pruning is applied each time a new scan completes. If the total number of completed scans exceeds your limit, the excess will be removed (oldest first).', LOOKSEE_L10N),
		),
		'type-core'=>array(
			__('This is a core WordPress file. It is very unusual for core files to be modified from their original versions. Give this one extra attention.', LOOKSEE_L10N),
		),
		'type-plugin'=>array(
			__('This is file is part of a WordPress plugin and so it is unusual to see local deviations from the official source files.', LOOKSEE_L10N),
			sprintf(
				__('That said, plugin and theme authors sometimes push code changes to WordPress without bumping the version number. This can throw older "versions" out of sync with the "matching" source hosted at %s.', LOOKSEE_L10N),
				'<a href="https://wordpress.org" target="_blank" rel="noopener">WP.org</a>'
			),
			__('Still, you should definitely take a look and make sure nothing bad is behind it. :)', LOOKSEE_L10N),
		),
		'type-theme'=>array(
			__('This is file is part of a WordPress theme and so it is unusual to see local deviations from the official source files.', LOOKSEE_L10N),
			sprintf(
				__('That said, plugin and theme authors sometimes push code changes to WordPress without bumping the version number. This can throw older "versions" out of sync with the "matching" source hosted at %s.', LOOKSEE_L10N),
				'<a href="https://wordpress.org" target="_blank" rel="noopener">WP.org</a>'
			),
			__('Still, you should definitely take a look and make sure nothing bad is behind it. :)', LOOKSEE_L10N),
		),
		'warning-chmod'=>array(
			sprintf(
				__('On Unix systems, every file and directory has a set of %s that dictates who can do what with it. This is a very important and basic security feature, particularly for web servers. When permissions are too lax, hackers might be able to do bad things.', LOOKSEE_L10N),
				'<a href="https://en.wikipedia.org/wiki/Chmod" target="_blank" rel="noopener">' . __('permissions', LOOKSEE_L10N) . '</a>'
			),
			sprintf(
				__('"Safe" file permissions will vary from server-to-server, but will typically either be %s or %s (your files are set to %s). Look-See will flag any files with looser permissions.', LOOKSEE_L10N),
				'<code>640</code>',
				'<code>644</code>',
				'<code>' . files::chmod() . '</code>'
			)
		),
		'warning-chown'=>array(
			sprintf(
				__('On Unix systems, every file and directory is assigned a specific "user" and "group". When combined with its %s, this determines whether or not a particular user is allowed to read, write, or execute a given path.', LOOKSEE_L10N),
				'<a href="https://en.wikipedia.org/wiki/Chmod" target="_blank" rel="noopener">' . __('permissions', LOOKSEE_L10N) . '</a>'
			),
			__('Generally speaking, all files for a given web site should usually belong to the same "user:group", and that "user:group" should have little to no system access beyond what is relevant for displaying the web site. Inconsistencies in ownership can result in permission conflicts (like an inability to read or write files), or allow a hacker to gain wider system access than they should.', LOOKSEE_L10N),
			sprintf(
				__('Look-See will flag any files with a user:group pair other than %s, the default for your server.', LOOKSEE_L10N),
				'<code class="looksee-file-path">' . files::chown() . '</code>'
			),
		),
		'warning-core-extra'=>array(
			__('WordPress designates certain areas for user-supplied content to reside. Unexpected files appearing outside of these areas is unusual and deserves your attention.', LOOKSEE_L10N),
			__('In some cases, these might be auto-generated files from plugins or themes, but in others, they might be a hidden backdoor left behind by a hacker.', LOOKSEE_L10N),
		),
		'warning-core-missing'=>array(
			__('The following files are normally part of fresh installs, but for some reason are missing on your system. This might mean your installation was only partly successful, or maybe a theme or plugin is just doing something odd.', LOOKSEE_L10N),
		),
		'warning-core-modified'=>array(
			__('Generally speaking, nobody should be making changes to the main WordPress files, or any of its themes or plugins. Those files will change whenever updates are applied, of course, but otherwise they should be identical to the hosted versions.', LOOKSEE_L10N),
			__('These files have been flagged as *not* matching their clean counterparts. Please take a look at them, and proceed with caution.', LOOKSEE_L10N),
			__('Now, before you have a heart attack, note that there are two reasons this could happen that do not involve hacking: 1) your server modified the files during the initial upload; 2) changes to the plugin or theme were published to WordPress, but the author forgot to bump the version.', LOOKSEE_L10N)
		),
		'warning-core-old'=>array(
			__('These are obsolete files left over from older versions of WordPress. They are not being used any more and should be removed. At best, they are wasting disk space; at worst, they might contain exploitable code that could put your site at risk.', LOOKSEE_L10N)
		),
		'warning-dev-file'=>array(
			__('All too often, development files – logs, backups, database dumps, etc. – are accidentally copied over to production environments, leaving them visible to the public. You should review and remove any such files, otherwise the information they contain could help hackers better target attacks against your web site.', LOOKSEE_L10N),
			sprintf(
				__("And just in case you were thinking, \"Well, these aren't linked to from anywhere, I'm safe!\" remember that humans are not very creative. Robots scour the internet looking for file variations like %s, %s, etc. If you really need to keep these files on the server, just move them above the web root to prevent them from being loaded in a web browser.", LOOKSEE_L10N),
				'<code>*.bak</code>',
				'<code>*.tmp</code>'
			)
		),
		'warning-mime'=>array(
			sprintf(
				__('By default, WordPress determines what kind of content may or may not be uploaded by looking at the file name. For example, a file called %s will be allowed because %s is allowed.', LOOKSEE_L10N),
				'<code>image.jpg</code>',
				'<code>.jpg</code>'
			),
			__('Unfortunately this ignores the fact that file names are completely arbitrary. Hackers can bypass name-based safeguards by simply giving a file a different extension. Haha.', LOOKSEE_L10N),
			__("Certain methods exist for determining a file's *true* type by examining its structure. Look-See performs these tests and will flag any files that are suspected to be something other than they appear.", LOOKSEE_L10N),
			__('This detection is not fool-proof, so please take a look at the flagged files and ignore any that are actually fine.', LOOKSEE_L10N),
		),
		'warning-php-eval'=>array(
			sprintf(
				__('Look-See includes several checks for dangerous PHP functions like %s, which is used to execute arbitrary PHP commands passed as a data string. This is a *very* bad idea. Haha.', LOOKSEE_L10N),
				'<a href="http://php.net/manual/en/function.eval.php" target="_blank" rel="noopener">eval()</a>'
			),
			__('If you discover that a plugin or theme is intentionally using this function, it is highly recommended you uninstall it and find a safer alternative.', LOOKSEE_L10N),
		),
		'warning-php-gibberish'=>array(
			__('Hackers usually attempt to obfuscate their malicious code by messing with the encoding or breaking it up into different functions. Look-See scans PHP files for long, unbroken strings of gibberish.', LOOKSEE_L10N),
			__("Being gibberish, it's impossible for the plugin to definitively say, \"This is bad.\", so please manually review the flagged files to see if there is anything you should be concerned about.", LOOKSEE_L10N),
		),
		'warning-php-phpinfo'=>array(
			sprintf(
				__('%s is a helpful developer function that dumps a ton of environmental information to the screen. That is A-OK when a site is being developed, but references should be removed once it is live, otherwise hackers can benefit from all the details it provides.', LOOKSEE_L10N),
				'<a href="http://php.net/manual/en/function.phpinfo.php" target="_blank" rel="noopener">phpinfo()</a>'
			),
		),
		'warning-php-system'=>array(
			sprintf(
				__('Look-See scans PHP files for wrapper functions like %s, %s, %s, %s, and %s that allow PHP to directly run shell commands. As you might suspect, this can have disastrous security consequences. Haha.', LOOKSEE_L10N),
				'<a href="http://php.net/manual/en/function.exec.php" target="_blank" rel="noopener">exec()</a>',
				'<a href="http://php.net/manual/en/function.passthru.php" target="_blank" rel="noopener">passthru()</a>',
				'<a href="http://php.net/manual/en/function.shell-exec.php" target="_blank" rel="noopener">shell_exec()</a>',
				'<a href="http://php.net/manual/en/function.system.php" target="_blank" rel="noopener">system()</a>',
				'<a href="http://php.net/manual/en/function.proc-open.php" target="_blank" rel="noopener">proc_open()</a>'
			),
			__('Not all implementations of these functions are inherently evil, but if handled improperly, could be bad news. Please review any flagged items carefully.', LOOKSEE_L10N)
		),
		'warning-timeout'=>array(
			__('The server was unable to scan these files. This usually means the file was too big for the poor server to handle, but could also indicate an inability for PHP to read it at all. It is worth manually double-checking these files to ensure their permissions are correctly set, etc.', LOOKSEE_L10N),
		),
		// @codingStandardsIgnoreEnd
	),
	'history'=>array(),
	'scan_id'=>-1,
	'warning_type'=>'',
	'section'=>'scan',
	'sectionTitles'=>array(
		'scan'=>__('New File Scan', LOOKSEE_L10N),
		'history'=>__('Scan History', LOOKSEE_L10N),
		'results'=>__('Scan Results', LOOKSEE_L10N),
	),
	'statuses'=>array(
		__('Initializing the scan.', LOOKSEE_L10N),
		__('Collecting WordPress checksums.', LOOKSEE_L10N),
		__('Collecting plugin checksums.', LOOKSEE_L10N),
		__('Collecting theme checksums.', LOOKSEE_L10N),
		__('Searching the local filesystem.', LOOKSEE_L10N),
		__('Finishing up the pre-scan.', LOOKSEE_L10N),
		__('Scanning files.', LOOKSEE_L10N),
		__('Done!', LOOKSEE_L10N),
	),
	'icons'=>array(
		'delete'=>'trash',
		'fix'=>'hammer',
		'ignore'=>'hidden',
		'view'=>'search',
	),
	'chmod'=>files::chmod(),
	'chown'=>files::chown(),
	'file'=>array(
		'content'=>'',
		'language'=>'',
		'path'=>'',
	),
);

// Add our current settings to the settings form. There's a few things
// to tweak along the way.
$settings = options::get();
unset($settings['license']);

// Convert bools to integers for Vue.js. Luckily we don't have to go too
// deep. Haha.
foreach ($settings as $k=>$v) {
	if (is_array($v)) {
		foreach ($settings[$k] as $k2=>$v2) {
			if (is_bool($v2)) {
				common\ref\cast::to_int($settings[$k][$k2]);
			}
			elseif (is_array($v2)) {
				foreach ($settings[$k][$k2] as $k3=>$v3) {
					if (is_bool($v3)) {
						common\ref\cast::to_int($settings[$k][$k2][$k3]);
					}
				}
			}
		}
	}
}

$settings['scan']['skip_size'] = round($settings['scan']['skip_size'] / 1024 / 1024, 1);
$settings['scan']['blacklist'] = implode("\n", $settings['scan']['blacklist']);
foreach ($settings as $k=>$v) {
	$data['forms']['settings'][$k] = $v;
}

// Is a scan already in progress?
if (!scan::is_locked() && false !== ($scan = scan::get_open_scan())) {
	$data['forms']['scan']['scan_id'] = $scan->get_scan_id();
}

// JSON doesn't appreciate broken UTF.
common\ref\sanitize::utf8($data);
?>
<script>var lookseeData=<?php echo json_encode($data, JSON_HEX_AMP); ?>;</script>
<div class="wrap" id="vue-scan" v-cloak>
	<h1>Look-See Security Scanner: {{ sectionTitles[section] }}</h1>

	<div class="notice notice-info looksee-hosting" v-if="slowScans">
		<div class="looksee-hosting--notice"><?php
			$out = array();

			$out[] = __("Look-See file scan operations are pretty resource-intensive — there's a lot to check! — but they should not be taking anywhere near as much time to complete as they have been for you.", LOOKSEE_L10N);

			$out[] = sprintf(
				__('If this notice persists, chances are your current web hosting is… not good. %s Haha.', LOOKSEE_L10N),
				'<em>' . __('Not good at all.', LOOKSEE_L10N) . '</em>'
			);

			$out[] = __('In the short term, you might be able to speed up scans by adding custom ignore rules, but you should really consider switching to a more competent hosting provider. Otherwise it is just money down the drain.', LOOKSEE_L10N);

			echo '<p>' . implode('</p><p>', $out) . '</p>';
		?></div>
		<div class="looksee-hosting--image">
			<img src="<?php echo LOOKSEE_PLUGIN_URL; ?>img/snail.jpg" width="158" height="75" alt="snail" class="looksee-hosting--snail" />
			<div class="looksee-hosting--source">
				By Jürgen Schoner
				[<a href="http://www.gnu.org/copyleft/fdl.html" target="_blank" rel="noopener">GFDL</a> or <a href="http://creativecommons.org/licenses/by-sa/3.0/" target="_blank" rel="noopener">CC-BY-SA-3.0</a>],
				via <a href="https://commons.wikimedia.org/wiki/Main_Page" target="_blank" rel="noopener">Wikimedia Commons</a>
			</div>
		</div>
	</div>

	<div class="updated" v-if="forms.scan.loading"><p><?php
		echo __('A file scan is underway. Please do not leave this page until it has finished.', LOOKSEE_L10N);
	?></p></div>
	<div class="updated" v-if="forms.settings.saved"><p><?php
		echo __('Your settings have been saved!', LOOKSEE_L10N);
	?></p></div>
	<div class="updated" v-if="forms.abort.saved"><p><?php
		echo __('The cancel request has been saved. The scan should stop soon.', LOOKSEE_L10N);
	?></p></div>

	<div class="error" v-for="error in forms.abort.errors"><p>{{error}}</p></div>
	<div class="error" v-for="error in forms.history.errors"><p>{{error}}</p></div>
	<div class="error" v-for="error in forms.scan.errors"><p>{{error}}</p></div>
	<div class="error" v-for="error in forms.settings.errors"><p>{{error}}</p></div>
	<div class="error" v-for="error in forms.file.errors"><p>{{error}}</p></div>


	<p>&nbsp;</p>
	<h3 class="nav-tab-wrapper">
		<a style="cursor: pointer;" class="nav-tab" v-bind:class="{'nav-tab-active' : section === 'scan'}" v-on:click.prevent="toggleSection('scan')">{{ sectionTitles.scan }}</a>

		<a v-if="history.length" style="cursor: pointer;" class="nav-tab" v-bind:class="{'nav-tab-active' : section === 'history'}" v-on:click.prevent="toggleSection('history')">{{ sectionTitles.history }}</a>

		<a v-if="scan_id && currentScan" style="cursor: pointer;" class="nav-tab" v-bind:class="{'nav-tab-active' : section === 'results'}" v-on:click.prevent="toggleSection('results')"><?php echo __('Scan', LOOKSEE_L10N); ?> #{{ scan_id }}</a>
	</h3>


	<div id="poststuff">

		<!-- ==============================================
		MAIN SCAN
		=============================================== -->
		<div id="post-body" class="metabox-holder looksee-columns" v-if="section === 'scan'" v-bind:class="{'one-two' : !forms.scan.loading}">

			<!-- Main -->
			<div class="postbox-container two">

				<div class="postbox" v-if="!forms.scan.loading">
					<h3 class="hndle"><?php echo __('New File Scan', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<?php
						// @codingStandardsIgnoreStart
						$out = array(
							__('Welcome to the file scan!', LOOKSEE_L10N),
							__("This scan will let you know if any official WordPress files – the program itself, as well as any hosted plugins and themes – have been modified from their original versions. Content that can't be matched this way will instead be checked from scan-to-scan, letting you know what is new, missing, or changed since the last scan.", LOOKSEE_L10N),
							__("Look-See also goes a bit deeper, finding potentially malicious code lurking in PHP files, locating developer files and backups (which shouldn't be stored on a public server), and other tasks of this sort.", LOOKSEE_L10N),
							__('Depending on the size of the site and power of the server, scans can take a little while to complete. Once you begin, do not navigate away from this page. The results will be displayed as soon as they are ready.', LOOKSEE_L10N),
						);
						// @codingStandardsIgnoreEnd

						echo '<p>' . implode('</p><p>', $out) . '</p>';
						?>

						<p><button type="button" class="button button-large button-primary" v-on:click.prevent="scanSubmit"><?php echo __('Start Scan!', LOOKSEE_L10N); ?></button>
					</div>
				</div>
				<div class="postbox" v-else>
					<h3 class="hndle"><?php echo __('Scan Status', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<ol class="looksee-scan--steps">
							<li v-for="(item, key) in statuses" class="looksee-scan--step" v-bind:class="{
								'is-active': key === statusIndex,
								'is-done': key < statusIndex,
								'is-pending': key > statusIndex
							}">
								<div class="looksee-scan--step--number">{{ key+1 }}.</div>
								<div class="looksee-scan--step--title">{{ item }}</div>
								<div class="looksee-scan--step--progress">
									<div class="looksee-scan--step--progress--inner" v-bind:style="key === statusIndex ? 'width: ' + forms.scan.progress + '%' : ''"></div>
								</div>
								<div class="looksee-scan--step--percent">
									<span v-if="key === statusIndex">{{ forms.scan.progress }}%</span>
									<span v-else-if="key < statusIndex">100%</span>
									<span v-else>0%</span>
								</div>
							</li>
						</ol>

						<p><button type="button" class="button button-small" v-on:click.prevent="abortSubmit" v-bind:disabled="forms.abort.loading || forms.abort.aborted"><?php echo __('Cancel Scan', LOOKSEE_L10N); ?></button></p>
					</div>
				</div>

			</div><!--.postbox-container-->

			<!-- Sidebar -->
			<div class="postbox-container one" v-if="!forms.scan.loading">

				<div class="postbox">
					<h3 class="hndle"><?php echo __('Settings', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<form method="post" action="<?php echo admin_url('admin-ajax.php'); ?>" v-form name="settings" v-on:submit.prevent="settingsSubmit">

							<div class="looksee-fieldset inline">
								<label for="scan-skip_cache">
									<input type="checkbox" id="scan-skip_cache" v-model.number="forms.settings.scan.skip_cache" v-bind:true-value="1" v-bind:false-value="0" />
									<?php echo __('Skip Cache', LOOKSEE_L10N); ?>
								</label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-skip_cache'}" v-on:click.prevent="toggleModal('scan-skip_cache')"></span>
							</div>

							<div class="looksee-fieldset inline">
								<label for="scan-skip_images">
									<input type="checkbox" id="scan-skip_images" v-model.number="forms.settings.scan.skip_images" v-bind:true-value="1" v-bind:false-value="0" />
									<?php echo __('Skip Images', LOOKSEE_L10N); ?>
								</label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-skip_images'}" v-on:click.prevent="toggleModal('scan-skip_images')"></span>
							</div>

							<div class="looksee-fieldset inline">
								<label for="scan-skip_media">
									<input type="checkbox" id="scan-skip_media" v-model.number="forms.settings.scan.skip_media" v-bind:true-value="1" v-bind:false-value="0" />
									<?php echo __('Skip Audio/Video', LOOKSEE_L10N); ?>
								</label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-skip_media'}" v-on:click.prevent="toggleModal('scan-skip_media')"></span>
							</div>

							<div class="looksee-fieldset inline">
								<label for="scan-skip_size"><?php echo __('Max File Size', LOOKSEE_L10N); ?></label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-skip_size'}" v-on:click.prevent="toggleModal('scan-skip_size')"></span>

								<input type="number" id="scan-skip_size" v-model.number="forms.settings.scan.skip_size" min="0" max="25" step=".1" required />

								<span class="looksee-fg-grey">&nbsp;<?php echo __('MB', LOOKSEE_L10N); ?></span>
							</div>

							<div class="looksee-fieldset inline">
								<label for="scan-batch_size"><?php echo __('Batch Size', LOOKSEE_L10N); ?></label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-batch_size'}" v-on:click.prevent="toggleModal('scan-batch_size')"></span>

								<input type="number" id="scan-batch_size" v-model.number="forms.settings.scan.batch_size" min="25" max="1000" step="25" required />

								<span class="looksee-fg-grey">&nbsp;<?php echo __('files', LOOKSEE_L10N); ?></span>
							</div>

							<div class="looksee-fieldset outline">
								<p>
									<label for="scan-blacklist"><?php echo __('Ignore Path(s)', LOOKSEE_L10N); ?></label>

									<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'scan-blacklist'}" v-on:click.prevent="toggleModal('scan-blacklist')"></span>
								</p>

								<p><textarea id="scan-blacklist" v-model.trim="forms.settings.scan.blacklist"></textarea></p>

								<p class="description"><?php
									echo sprintf(
										__('Enter any custom exclusion rules above, one per line. Wildcards like %s are supported. Paths should be relative to the base directory, %s.', LOOKSEE_L10N),
										'<code>*</code>',
										'<code class="looksee-file-path">' . files::get_base_dir() . '</code>'
									);
								?></p>
							</div>

							<div class="looksee-fieldset outline">
								<button class="button button-large button-primary" type="submit" v-bind:disabled="forms.settings.loading"><?php echo __('Save Settings', LOOKSEE_L10N); ?></button>
							</div>

						</form>
					</div>
				</div>

			</div><!--.postbox-container-->

		</div><!--#post-body-->



		<!-- ==============================================
		HISTORY
		=============================================== -->
		<div id="post-body" class="metabox-holder looksee-columns one-two fixed" v-if="section === 'history'">

			<!-- Main -->
			<div class="postbox-container two">

				<div class="postbox">
					<h3 class="hndle"><?php echo __('Completed Scans', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<table class="looksee-results">
							<thead>
								<tr>
									<th><?php echo __('Finished', LOOKSEE_L10N); ?></th>
									<th><?php echo __('Status', LOOKSEE_L10N); ?></th>
									<th style="text-align: right;"><?php echo __('Files', LOOKSEE_L10N); ?></th>
									<th style="text-align: right;"><?php echo __('Scanned', LOOKSEE_L10N); ?></th>
									<th style="text-align: right;"><?php echo __('Skipped', LOOKSEE_L10N); ?></th>
									<th style="text-align: right;"><?php echo __('Warnings', LOOKSEE_L10N); ?></th>
									<th></th>
								</tr>
							</thead>
							<tbody>
								<tr v-for="item in history">
									<td>
										{{ item.date_finished }}<br>
										{{ item.elapsed | relativeTime }}
									</td>
									<td v-bind:class="{'warning' : item.error}">{{ item.status }}</td>
									<td style="text-align: right;">{{ item.results.total }}</td>
									<td style="text-align: right;" v-bind:class="{'looksee-fg-grey' : !item.results.scanned }">{{ item.results.scanned }}</td>
									<td style="text-align: right;" v-bind:class="{'looksee-fg-grey' : !item.results.skipped }">{{ item.results.skipped }}</td>
									<td style="text-align: right;" v-bind:class="{'looksee-fg-grey' : !item.results.warnings, 'warning': item.results.warnings }">{{ item.results.warnings }}</td>
									<td><button type="button" class="button button-small" v-on:click.prevent="toggleResult(item.scan_id)"><?php echo __('Details', LOOKSEE_L10N); ?></button></td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>

			</div><!--.postbox-container-->

			<!-- Sidebar -->
			<div class="postbox-container one">

				<div class="postbox">
					<h3 class="hndle"><?php echo __('Data Retention', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<form method="post" action="<?php echo admin_url('admin-ajax.php'); ?>" v-form name="settings" v-on:submit.prevent="settingsSubmit">

							<div class="looksee-fieldset inline">
								<label for="prune-active">
									<input type="checkbox" id="prune-active" v-model.number="forms.settings.prune.active" v-bind:true-value="1" v-bind:false-value="0" />
									<?php echo __('Enable Pruning', LOOKSEE_L10N); ?>
								</label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'prune-active'}" v-on:click.prevent="toggleModal('prune-active')"></span>
							</div>

							<div class="looksee-fieldset inline" v-if="forms.settings.prune.active">
								<label for="prune-limit"><?php echo __('Maximum Scans', LOOKSEE_L10N); ?></label>

								<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'prune-limit'}" v-on:click.prevent="toggleModal('prune-limit')"></span>

								<input type="number" id="prune-limit" v-model.number="forms.settings.prune.limit" min="1" max="25" step="1" required />
							</div>

							<div class="looksee-fieldset outline">
								<button class="button button-large button-primary" type="submit" v-bind:disabled="forms.settings.loading"><?php echo __('Save Settings', LOOKSEE_L10N); ?></button>
							</div>

						</form>
					</div>
				</div>

			</div><!--.postbox-container-->

		</div><!--#post-body-->



		<!-- ==============================================
		RESULTS
		=============================================== -->
		<div id="post-body" class="metabox-holder looksee-columns one-two fixed" v-if="section === 'results' && scan_id">

			<!-- Main -->
			<div class="postbox-container two">

				<!-- NOTHING? -->
				<div class="postbox" v-if="
					!currentScan.results.warnings &&
					!currentScan.results.warnings_core &&
					!currentScan.details.modified.length &&
					!currentScan.details.new.length &&
					!currentScan.details.deleted.length
				">
					<h3 class="hndle" v-if="!currentScan.error"><?php echo __('All Good!', LOOKSEE_L10N); ?></h3>
					<h3 class="hndle" v-else><?php echo __('Incomplete Scan', LOOKSEE_L10N); ?></h3>

					<div class="inside" v-if="!currentScan.error">
						<p><?php echo __('This scan did not turn up anything unusual.', LOOKSEE_L10N); ?></p>
					</div>
					<div class="inside" v-else>
						<p><?php echo __('This scan did not finish running.', LOOKSEE_L10N); ?></p>
					</div>
				</div>

				<!-- WARNINGS -->
				<div class="postbox" v-if="currentScan.results.warnings">
					<h3 class="hndle">
						<fieldset v-if="currentScan.details.warning_types.length > 1" class="looksee-warnings--filter">
							<label for="warnings-filter"><?php echo __('Filter', LOOKSEE_L10N);?>:</label>
							<select id="warnings-filter" v-model="warning_type">
								<option value=""><?php echo __('All Warnings', LOOKSEE_L10N); ?></option>
								<option v-for="option in currentScan.details.warning_types" v-bind:value="option">{{ option }}</option>
							</select>
						</fieldset>

						<?php echo __('Warnings', LOOKSEE_L10N); ?>

						<div class="looksee-clearfix"></div>
					</h3>

					<div class="inside">
						<p><?php
							echo __('The following warnings were flagged during the scan. These items are not necessarily dire, but you should review each issue carefully.', LOOKSEE_L10N);
						?></p>

						<table class="looksee-results">
							<thead>
								<tr>
									<th><?php echo __('Warning', LOOKSEE_L10N); ?></th>
									<th><?php echo __('File', LOOKSEE_L10N); ?></th>
									<th v-if="currentScan.details.actionable" class="show-desktop"><?php echo __('Actions', LOOKSEE_L10N); ?></th>
								</tr>
							</thead>
							<tbody>
								<tr v-for="item in currentWarnings">
									<td>
										<span class="looksee-scan--warning">{{ item.warningText }}</span>

										<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'warning-' + item.warning}" v-on:click.prevent="toggleModal('warning-' + item.warning)"></span>
									</td>
									<td>
										<code class="looksee-file-path">{{ item.file }}</code>

										<span v-if="item.type" class="dashicons dashicons-warning looksee-info-toggle" v-bind:class="{'is-active' : modal === 'type-' + item.type}" v-on:click.prevent="toggleModal('type-' + item.type)"></span>

										<div class="looksee-scan--extra" v-if="item.extra">{{ item.extra }}</div>
									</td>
									<td v-if="currentScan.details.actionable" class="show-desktop">
										<div v-if="item.actions.length" class="looksee-scan--actions">

											<button type="button" class="looksee-scan--action view" v-on:click.prevent="filePreSubmit('view', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('view') === -1">
												<span class="dashicons" v-bind:class="'dashicons-search'"></span>
											</button>

											<button type="button" class="looksee-scan--action fix" v-on:click.prevent="filePreSubmit('fix', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('fix') === -1">
												<span class="dashicons" v-bind:class="'dashicons-hammer'"></span>
											</button>

											<button type="button" class="looksee-scan--action ignore" v-on:click.prevent="filePreSubmit('ignore', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('ignore') === -1">
												<span class="dashicons" v-bind:class="'dashicons-hidden'"></span>
											</button>

											<button type="button" class="looksee-scan--action delete" v-on:click.prevent="filePreSubmit('delete', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('delete') === -1">
												<span class="dashicons" v-bind:class="'dashicons-trash'"></span>
											</button>

										</div>
									</td>
								</tr>
							</tbody>
						</table>

					</div>
				</div>

				<!-- CHANGES -->
				<div class="postbox" v-if="currentScan.details.modified.length || currentScan.details.new.length || currentScan.details.deleted.length">
					<h3 class="hndle"><?php echo __('File Changes', LOOKSEE_L10N); ?></h3>

					<div class="inside">
						<p><?php
							echo __('The following files differ from their official counterparts, or have changed since the last time a scan was performed.', LOOKSEE_L10N);
						?></p>

						<table class="looksee-results">
							<thead>
								<tr>
									<th><?php echo __('Status', LOOKSEE_L10N); ?></th>
									<th><?php echo __('File', LOOKSEE_L10N); ?></th>
								</tr>
							</thead>
							<tbody>
								<tr v-for="item in currentScan.details.modified">
									<td>
										<?php echo __('Modified', LOOKSEE_L10N); ?>
									</td>
									<td>
										<code class="looksee-file-path">{{ item.file }}</code>

										<span v-if="item.type" class="dashicons dashicons-warning looksee-info-toggle" v-bind:class="{'is-active' : modal === 'type-' + item.type}" v-on:click.prevent="toggleModal('type-' + item.type)"></span>
									</td>
								</tr>
								<tr v-for="item in currentScan.details.new">
									<td>
										<?php echo __('New', LOOKSEE_L10N); ?>
									</td>
									<td>
										<code class="looksee-file-path">{{ item.file }}</code>

										<span v-if="item.type" class="dashicons dashicons-warning looksee-info-toggle" v-bind:class="{'is-active' : modal === 'type-' + item.type}" v-on:click.prevent="toggleModal('type-' + item.type)"></span>
									</td>
								</tr>
								<tr v-for="item in currentScan.details.deleted">
									<td>
										<?php echo __('Deleted', LOOKSEE_L10N); ?>
									</td>
									<td>
										<code class="looksee-file-path">{{ item.file }}</code>

										<span v-if="item.type" class="dashicons dashicons-warning looksee-info-toggle" v-bind:class="{'is-active' : modal === 'type-' + item.type}" v-on:click.prevent="toggleModal('type-' + item.type)"></span>
									</td>
								</tr>
							</tbody>
						</table>

					</div>
				</div>

				<!-- WARNINGS -->
				<div class="postbox" v-if="currentScan.results.warnings_core">
					<h3 class="hndle">
						<?php echo __('Notices: Third-Party Content', LOOKSEE_L10N); ?>
						<div class="looksee-clearfix"></div>
					</h3>

					<div class="inside">
						<p><?php
							echo sprintf(
								__('The following files %s match clean copies from WordPress — all good there! — but the Look-See scan still raised some flags.', LOOKSEE_L10N),
								'<em>' . __('do', LOOKSEE_L10N) . '</em>'
							);
						?></p>

						<p><?php
							echo sprintf(
								__("This doesn't necessarily mean that anything is wrong, but if you have an eye for code, you should double-check the authors didn't do something (unintentionally) dangerous.", LOOKSEE_L10N),
								'<em>' . __('do', LOOKSEE_L10N) . '</em>'
							);
						?></p>

						<table class="looksee-results">
							<thead>
								<tr>
									<th><?php echo __('Warning', LOOKSEE_L10N); ?></th>
									<th><?php echo __('File', LOOKSEE_L10N); ?></th>
									<th v-if="currentScan.details.actionable_core" class="show-desktop"><?php echo __('Actions', LOOKSEE_L10N); ?></th>
								</tr>
							</thead>
							<tbody>
								<tr v-for="item in currentScan.details.warnings_core">
									<td>
										<span class="looksee-scan--warning">{{ item.warningText }}</span>

										<span class="dashicons dashicons-editor-help looksee-info-toggle" v-bind:class="{'is-active' : modal === 'warning-' + item.warning}" v-on:click.prevent="toggleModal('warning-' + item.warning)"></span>
									</td>
									<td>
										<code class="looksee-file-path">{{ item.file }}</code>

										<span v-if="item.type" class="dashicons dashicons-warning looksee-info-toggle" v-bind:class="{'is-active' : modal === 'type-' + item.type}" v-on:click.prevent="toggleModal('type-' + item.type)"></span>

										<div class="looksee-scan--extra" v-if="item.extra">{{ item.extra }}</div>
									</td>
									<td v-if="currentScan.details.actionable_core" class="show-desktop">
										<div v-if="item.actions.length" class="looksee-scan--actions">

											<button type="button" class="looksee-scan--action view" v-on:click.prevent="filePreSubmit('view', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('view') === -1">
												<span class="dashicons" v-bind:class="'dashicons-search'"></span>
											</button>

											<button type="button" class="looksee-scan--action fix" v-on:click.prevent="filePreSubmit('fix', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('fix') === -1">
												<span class="dashicons" v-bind:class="'dashicons-hammer'"></span>
											</button>

											<button type="button" class="looksee-scan--action ignore" v-on:click.prevent="filePreSubmit('ignore', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('ignore') === -1">
												<span class="dashicons" v-bind:class="'dashicons-hidden'"></span>
											</button>

											<button type="button" class="looksee-scan--action delete" v-on:click.prevent="filePreSubmit('delete', item.file, item.hash)" v-bind:disabled="forms.file.loading || item.actions.indexOf('delete') === -1">
												<span class="dashicons" v-bind:class="'dashicons-trash'"></span>
											</button>

										</div>
									</td>
								</tr>
							</tbody>
						</table>

					</div>
				</div>

			</div><!--.postbox-container-->

			<!-- Sidebar -->
			<div class="postbox-container one">
				<div class="postbox">
					<h3 class="hndle"><?php echo __('Scan', LOOKSEE_L10N); ?> #{{ currentScan.scan_id }}</h3>
					<div class="inside">
						<table class="looksee-meta">
							<tbody>
								<tr>
									<th scope="row"><?php echo __('Started', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.date_created }}</td>
								</tr>
								<tr>
									<th scope="row"><?php echo __('Finished', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.date_finished }}</td>
								</tr>
								<tr>
									<th scope="row"><?php echo __('Elapsed', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.elapsed | relativeTime }}</td>
								</tr>
								<tr>
									<th scope="row" v-bind:class="{'looksee-fg-orange' : currentScan.error}"><?php echo __('Status', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.status }}</td>
								</tr>
								<tr>
									<th scope="row"><?php echo __('Files', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.results.total }}</td>
								</tr>
								<tr>
									<th scope="row"><?php echo __('Scanned', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.results.scanned }}</td>
								</tr>
								<tr>
									<th scope="row"><?php echo __('Skipped', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.results.skipped }}</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>

				<div v-if="currentScan.details.actionable" class="postbox show-desktop">
					<h3 class="hndle"><?php echo __('Legend', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<legend class="looksee-scan--legend">
							<div class="looksee-scan--legend--key">
								<div class="looksee-scan--action view">
									<span class="dashicons dashicons-search"></span>
								</div>
								<?php echo __('View File', LOOKSEE_L10N); ?>
							</div>

							<div class="looksee-scan--legend--key">
								<div class="looksee-scan--action fix">
									<span class="dashicons dashicons-hammer"></span>
								</div>
								<?php echo __('Fix Issue', LOOKSEE_L10N); ?>
							</div>

							<div class="looksee-scan--legend--key">
								<div class="looksee-scan--action ignore">
									<span class="dashicons dashicons-hidden"></span>
								</div>
								<?php echo __('Ignore File', LOOKSEE_L10N); ?>
							</div>

							<div class="looksee-scan--legend--key">
								<div class="looksee-scan--action delete">
									<span class="dashicons dashicons-trash"></span>
								</div>
								<?php echo __('Delete File', LOOKSEE_L10N); ?>
							</div>
						</legend>
					</div>
				</div>

				<div class="postbox">
					<h3 class="hndle"><?php echo __('Settings', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<table class="looksee-meta">
							<tbody>
								<tr>
									<th scope="row"><?php echo __('Skip', LOOKSEE_L10N); ?></th>
									<td>
										<div v-if="currentScan.env.scan.skip_cache"><?php echo __('Cache'); ?></div>
										<div v-if="currentScan.env.scan.skip_media"><?php echo __('Audio/Video'); ?></div>
										<div v-if="currentScan.env.scan.skip_images"><?php echo __('Images'); ?></div>
										<div v-for="item in currentScan.env.scan.blacklist">{{ item }}</div>
									</td>
								</tr>
								<tr v-if="currentScan.env.scan.skip_size > 0">
									<th scope="row"><?php echo __('Max Size', LOOKSEE_L10N); ?></th>
									<td>{{ Math.round(currentScan.env.scan.skip_size / 1024 / 1024 * 10) / 10 }} MB</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>

				<div class="postbox">
					<h3 class="hndle"><?php echo __('Sources', LOOKSEE_L10N); ?></h3>
					<div class="inside">
						<table class="looksee-meta small">
							<tbody>
								<tr>
									<th scope="row"><?php echo __('WordPress', LOOKSEE_L10N); ?></th>
									<td>{{ currentScan.env.core.version }}</td>
									<td>
										<span v-if="currentScan.env.core.checksums" class="dashicons dashicons-info looksee-info-toggle" v-bind:class="{'is-active' : modal === 'checksums'}" v-on:click.prevent="toggleModal('checksums')"></span>
									</td>
								</tr>
								<tr v-for="item in currentScan.env.plugins">
									<th scope="row">{{ item.name }}</th>
									<td>{{ item.version }}</td>
									<td>
										<span v-if="item.checksums" class="dashicons dashicons-info looksee-info-toggle" v-bind:class="{'is-active' : modal === 'checksums'}" v-on:click.prevent="toggleModal('checksums')"></span>
									</td>
								</tr>
								<tr v-for="item in currentScan.env.themes">
									<th scope="row">{{ item.name }}</th>
									<td>{{ item.version }}</td>
									<td>
										<span v-if="item.checksums" class="dashicons dashicons-info looksee-info-toggle" v-bind:class="{'is-active' : modal === 'checksums'}" v-on:click.prevent="toggleModal('checksums')"></span>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>
			</div>

		</div><!--#post-body-->



		<?php if (options::is_pro()) { ?>
			<!-- ==============================================
			ACTION CONFIRMATION MODAL
			=============================================== -->
			<transition name="fade">
				<div v-if="forms.file.confirming" class="looksee-confirmation" v-on:click.self="forms.file.confirming=false; forms.file.loading=false;">
					<div class="postbox looksee-confirmation--inner">
						<h3 class="hndle looksee-confirmation--title"><?php echo __('Last Chance', LOOKSEE_L10N); ?>&hellip;</h3>

						<div class="inside">
							<div class="looksee-confirmation--text" v-if="forms.file.action === 'looksee_ajax_file_delete'"><?php
								echo sprintf(
									__('Are you absolutely sure you want to delete %s? This cannot be undone, and if this file is required — by a theme, plugin, blog post, etc. — things could break.', LOOKSEE_L10N),
									'<code class="looksee-file-path">{{ forms.file.file_path }}</code>'
								) . '<br><br>' .
								__('Please make sure you have a full backup of your site files and database before making changes to the filesystem.', LOOKSEE_L10N);
							?></div>

							<div class="looksee-confirmation--text" v-if="forms.file.action === 'looksee_ajax_file_fix'"><?php
								echo sprintf(
									__('Are you sure you want Look-See to try to automatically fix some of the issues affecting %s?', LOOKSEE_L10N),
									'<code class="looksee-file-path">{{ forms.file.file_path }}</code>'
								) . '<br><br>' .
								__('Please make sure you have a full backup of your site files and database before making changes to the filesystem.', LOOKSEE_L10N);
							?></div>

							<div class="looksee-confirmation--text" v-if="forms.file.action === 'looksee_ajax_file_ignore'"><?php
								echo sprintf(
									__('Are you sure you would like to ignore %s from future scans? This will prevent you from learning of file changes or other warnings affecting this file.', LOOKSEE_L10N),
									'<code class="looksee-file-path">{{ forms.file.file_path }}</code>'
								) . '<br>&nbsp;<br>' .
								__('This action is, at least, reversible. If you change your mind, just locate and remove the ignore entry in the main scan settings.', LOOKSEE_L10N);
							?></div>

							<div class="looksee-confirmation--buttons">
								<button type="button" class="button button-large looksee-confirmation--button" v-on:click.prevent="forms.file.confirming=false; forms.file.loading=false;"><?php echo __('Cancel', LOOKSEE_L10N); ?></button>

								<button type="button" class="button button-primary button-large looksee-confirmation--button" v-on:click.prevent="fileSubmit()"><?php echo __('Proceed', LOOKSEE_L10N); ?></button>
							</div>
						</div>
					</div>
				</div>
			</transition>



			<!-- ==============================================
			FILE VIEW MODAL
			=============================================== -->
			<transition name="fade">
				<div v-if="file.content" class="looksee-file" v-on:click.self="file.content=''">
					<div class="postbox looksee-file--inner">
						<h3 class="hndle looksee-file--title">
							<span class="dashicons dashicons-dismiss looksee-file--close" v-on:click.prevent="file.content=''"></span>

							{{ file.path }}
						</h3>

						<div class="inside">
							<pre class="line-numbers" v-bind:class="'language-' + file.language"><code>{{ file.content }}</code></pre>
						</div>
					</div>
				</div>
			</transition>
		<?php } ?>

	</div><!--#poststuff-->



	<!-- ==============================================
	HELP MODAL
	=============================================== -->
	<transition name="fade">
		<div v-if="modal" class="looksee-modal">
			<span class="dashicons dashicons-dismiss looksee-modal--close" v-on:click.prevent="toggleModal('')"></span>
			<div class="looksee-modal--inner">
				<p v-for="p in modals[modal]" v-html="p"></p>
			</div>
		</div>
	</transition>
</div><!--.wrap-->
